c     ****************************************************************
c     * cmanager: Managing Cosmos Simulation
c     ****************************************************************
      subroutine cmanager
      implicit none
#include "Zevhnp.h"

                           
c      
      call creadParam(5)        ! read execution conditions from stdin
#ifdef NEXT486
      if( index(IntModel, 'fritiof1.6') .gt. 0 ) then
         call cerrorMsg('fritiof1.6 cannot be used'//
     *  ' for NEXT-Absoft Fortran', 0)
      endif
#endif
      call cbeginRun            ! initialize the simulation
      call ceventLoop           ! begin simulation and enter  event Loop
      call cendRun              ! close the simulation
      end
